import os

import pytest
import subprocess
from tenacity import retry, stop_after_attempt, wait_fixed
from kubernetes import client, config

@pytest.mark.integration_only
def test_health_check():
    """
    Calls health check endpoint

    """
    call_health_check()


@retry(stop=stop_after_attempt(2), wait=wait_fixed(1))
def call_health_check():
    es_config_job_name = os.getenv('ES_CONFIG_JOB_NAME')
    print(es_config_job_name)

    es_config_job_namespace = os.getenv('ES_CONFIG_JOB_NAMESPACE')
    print(es_config_job_namespace)

    config.load_incluster_config()
    batch_v1 = client.BatchV1Api()
    api_response = batch_v1.read_namespaced_job_status(
                name=f"{es_config_job_name}",
                namespace=f"{es_config_job_namespace}")
    print("Job status='%s'" % str(api_response.status))
    result = api_response.status.succeeded
    assert result == 1

